@@ -1,6 +1,6 @@
 
 colMinsMaxs <- function(x) {
-	x <- .Call('Rfast_col_min_max', PACKAGE = 'Rfast',x)
+	x <- .Call(Rfast_col_min_max,x)
 	rownames(x) <- c("min","max")
 	x
 }
\ No newline at end of file
