@@ -1,6 +1,6 @@
 glm_poisson <- function (x, y, full = FALSE,tol = 1e-09) {
     x <- model.matrix(y ~ ., data.frame(x))
-    mod <- .Call("Rfast_glm_poisson", x, y, sum(y * log(y), na.rm = TRUE),tol)
+    mod <- .Call(Rfast_glm_poisson, x, y, sum(y * log(y), na.rm = TRUE),tol)
     res <- list(be = mod$be, devi = mod$deviance)
     if (full) {
         be <- mod$be
