@@ -1,5 +1,5 @@
 permcor <- function (x, y, R = 999) {
-  a <- as.vector( .Call("Rfast_perm_cor", PACKAGE = "Rfast", x, y, R) )
+  a <- as.vector( .Call(Rfast_perm_cor, x, y, R) )
   names(a) <- c("cor", "p-value")  
   a
 }
\ No newline at end of file
