@@ -1,4 +1,4 @@
 
 permutation <- function(x,nperm=gamma(length(x)+1)) {
-  .Call('Rfast_permutation', PACKAGE = 'Rfast',x,nperm)
+  .Call(Rfast_permutation,x,nperm)
 }
\ No newline at end of file
