@@ -4,13 +4,13 @@ quasipoisson.anovas <- function (y, ina, logged = FALSE) {
     k <- length(ni)
     n <- sum(ni)
     si <- rowsum(y, ina)
-    sy <- colsums(si)
+    sy <- Rfast::colsums(si)
     mi <- si/ni
-    d1 <- colsums(si * log(mi))
+    d1 <- Rfast::colsums(si * log(mi))
     d0 <- sy * log(sy/n)
     up <- ( 2 * d1 - 2 * d0 ) / (k - 1)
     yi2 <- rowsum(y^2, ina)/mi
-    phi <- ( colsums(yi2) - sy ) / (n - k)
+    phi <- ( Rfast::colsums(yi2) - sy ) / (n - k)
     stat <- up / phi
     pvalue <- pf(stat, k - 1, n - k, lower.tail = FALSE, log.p = logged)
     cbind(stat, pvalue, phi)
