@@ -1,5 +1,5 @@
 rmvnorm <- function(n, mu, sigma) {
    p <- length(mu)
-   x <- matrix(RcppZiggurat::zrnorm(n * p), ncol = p)
+   x <- Rfast::matrnorm(n, p)
    x %*% chol(sigma) + rep(mu, rep(n, p) )
 }
\ No newline at end of file
