@@ -1,4 +1,4 @@
 
 rowShuffle <- function(x) {
-	.Call('Rfast_row_shuffle',x)
+	.Call(Rfast_row_shuffle,x)
 }
\ No newline at end of file
