@@ -1,6 +1,6 @@
 
 rowTrueFalse <- function(x) {
-  x <- .Call('Rfast_row_true_false', PACKAGE = 'Rfast',x)
+  x <- .Call(Rfast_row_true_false,x)
   rownames(x) <- c("FALSE","TRUE")
   x
 }
\ No newline at end of file
