@@ -1,5 +1,5 @@
 watson <- function(u) {
-  u <- Sort(u) / (2 * pi)
+  u <- Rfast::Sort(u) / (2 * pi)
   n <- length(u)
   i <- (1:n)/n
   Wn <- sum( ( ( u - i + 0.5/n ) - ( sum(u) / n - 0.5 ) )^2 ) + 1 / ( 12 * n )
